@@ -7,10 +7,7 @@
 # the same terms as the Perl 5 programming language system itself.
 #
 package Riak::Client;
-{
-  $Riak::Client::VERSION = '1.95';
-}
-
+$Riak::Client::VERSION = '1.96';
 use 5.010;
 use Riak::Client::PBC;
 use Type::Params qw(compile);
@@ -73,10 +70,10 @@ has port    => ( is => 'ro', isa => Int,  required => 1 );
 has r       => ( is => 'ro', isa => Int,  default  => sub {2} );
 has w       => ( is => 'ro', isa => Int,  default  => sub {2} );
 has dw      => ( is => 'ro', isa => Int,  default  => sub {1} );
-has connection_timeout => ( is => 'ro',                 isa => Num,  default  => sub {5} );
-has read_timeout       => ( is => 'ro', predicate => 1, isa => Num,  default  => sub {5} );
-has write_timeout      => ( is => 'ro', predicate => 1, isa => Num,  default  => sub {5} );
-has no_delay           => ( is => 'ro',                 isa => Bool, default  => sub {0} );
+has connection_timeout => ( is => 'ro', isa => Num,  default  => sub {5} );
+has read_timeout       => ( is => 'ro', isa => Num,  default  => sub {5} );
+has write_timeout      => ( is => 'ro', isa => Num,  default  => sub {5} );
+has no_delay           => ( is => 'ro', isa => Bool, default  => sub {0} );
 
 
 has no_auto_connect => ( is => 'ro', isa => Bool,  default  => sub {0} );
@@ -101,16 +98,13 @@ sub _build__socket {
     croak "Error ($!), can't connect to $host:$port"
       unless defined $socket;
 
-    $self->has_read_timeout || $self->has_write_timeout
-      or return $socket;
-
-    # enable read and write timeouts on the socket
-    IO::Socket::Timeout->enable_timeouts_on($socket);
-    # setup the timeouts
-    $self->has_read_timeout
-      and $socket->read_timeout($self->read_timeout);
-    $self->has_write_timeout
-      and $socket->write_timeout($self->write_timeout);
+    if ($self->read_timeout || $self->write_timeout) {
+        # enable read and write timeouts on the socket
+        IO::Socket::Timeout->enable_timeouts_on($socket);
+        # setup the timeouts
+        $socket->read_timeout($self->read_timeout);
+        $socket->write_timeout($self->write_timeout);
+    }
 
     use Socket qw(IPPROTO_TCP TCP_NODELAY);
     $self->no_delay
@@ -495,8 +489,7 @@ sub _handle_get_bucket_props_response {
 
 sub set_bucket_props {
     state $check = compile( Any, Str, 
-                            Dict[ n_val => Optional[Int],
-                                  allow_mult => Optional[Bool] ],
+                            Dict,
                             Optional[CodeRef] );
     my ( $self, $bucket, $props, $cb ) = $check->(@_);
     $props->{n_val} && $props->{n_val} < 0 and croak 'n_val should be possitive integer';
@@ -739,7 +732,7 @@ Riak::Client - Fast and lightweight Perl client for Riak
 
 =head1 VERSION
 
-version 1.95
+version 1.96
 
 =head1 SYNOPSIS
 
